==> apacheds-protocol-kerberos-1.5.4-sources.jar: org/apache/directory/server/kerberos/protocol/KerberosUdpProtocolCodecFactory.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server.kerberos.protocol;


import org.apache.mina.filter.codec.ProtocolCodecFactory;
import org.apache.mina.filter.codec.ProtocolDecoder;
import org.apache.mina.filter.codec.ProtocolEncoder;


/**
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 543388 $, $Date: 2007-06-01 00:48:03 -0400 (Fri, 01 Jun 2007) $
 */
public class KerberosUdpProtocolCodecFactory implements ProtocolCodecFactory
{
    private static final KerberosUdpProtocolCodecFactory INSTANCE = new KerberosUdpProtocolCodecFactory();


    /**
     * Returns the singleton {@link KerberosUdpProtocolCodecFactory}.
     *
     * @return The singleton {@link KerberosUdpProtocolCodecFactory}.
     */
    public static KerberosUdpProtocolCodecFactory getInstance()
    {
        return INSTANCE;
    }


    private KerberosUdpProtocolCodecFactory()
    {
        // Private constructor prevents instantiation outside this class.
    }


    public ProtocolEncoder getEncoder()
    {
        // Create a new encoder.
        return new KerberosUdpEncoder();
    }


    public ProtocolDecoder getDecoder()
    {
        // Create a new decoder.
        return new KerberosUdpDecoder();
    }
}

==> apacheds-protocol-kerberos-1.5.6-sources.jar: org/apache/directory/server/kerberos/protocol/KerberosUdpProtocolCodecFactory.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */
package org.apache.directory.server.kerberos.protocol;


import org.apache.mina.core.session.IoSession;
import org.apache.mina.filter.codec.ProtocolCodecFactory;
import org.apache.mina.filter.codec.ProtocolDecoder;
import org.apache.mina.filter.codec.ProtocolEncoder;


/**
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 725712 $, $Date: 2008-12-11 16:32:04 +0100 (Jeu, 11 déc 2008) $
 */
public class KerberosUdpProtocolCodecFactory implements ProtocolCodecFactory
{
    private static final KerberosUdpProtocolCodecFactory INSTANCE = new KerberosUdpProtocolCodecFactory();


    /**
     * Returns the singleton {@link KerberosUdpProtocolCodecFactory}.
     *
     * @return The singleton {@link KerberosUdpProtocolCodecFactory}.
     */
    public static KerberosUdpProtocolCodecFactory getInstance()
    {
        return INSTANCE;
    }


    private KerberosUdpProtocolCodecFactory()
    {
        // Private constructor prevents instantiation outside this class.
    }


    public ProtocolEncoder getEncoder( IoSession session )
    {
        // Create a new encoder.
        return new KerberosUdpEncoder();
    }


    public ProtocolDecoder getDecoder( IoSession session )
    {
        // Create a new decoder.
        return new KerberosUdpDecoder();
    }
}
